/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl.layout;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JComponent;

import de.javagl.swogl.IntersectionInfo;
import de.javagl.swogl.SwoglComponent;
import de.javagl.swogl.SwoglContainer;
import de.javagl.swogl.interaction.Control;

/**
 * Implementation of a {@link Control} for a {@link GridLayout3D}.
 */
public class GridLayoutControl implements Control
{
    /**
     * The {@link GridLayout3D} this control operates on
     */
    private GridLayout3D gridLayout;
    
    /**
     * The listener that will be attached to the component
     */
    class Listener extends MouseAdapter implements MouseListener
    {
        @Override
        public void mouseClicked(MouseEvent event)
        {
            if (isEnabled())
            {
                if (event.getClickCount() == 2)
                {
                    IntersectionInfo intersectionInfo = 
                        swoglContainer.computeIntersectionInfo(
                            event.getPoint());
                    if (intersectionInfo != null)
                    {
                        SwoglComponent swoglComponent = 
                            intersectionInfo.getSwoglComponent();
                        gridLayout.zoomTo(swoglComponent);
                    }
                    if (intersectionInfo == null || 
                        event.getButton() == MouseEvent.BUTTON3)
                    {
                        gridLayout.zoomTo(null);
                    }
                }
            }
        }
    }
    /**
     * The listener that will be attached to the component
     */
    private Listener listener = new Listener();
    
    /**
     * Whether this control is currently enabled
     */
    private boolean enabled = true;

    /**
     * The SwoglContainer
     */
    private SwoglContainer swoglContainer;
    
    /**
     * Creates a new GridLayoutControl for the given {@link GridLayout3D}.
     * 
     * @param gridLayout The layout
     * @param swoglContainer The SwoglContainer
     */
    public GridLayoutControl(
        GridLayout3D gridLayout, SwoglContainer swoglContainer)
    {
        this.gridLayout = gridLayout;
        this.swoglContainer = swoglContainer;
    }
    
    /**
     * Will be called when the "browse mode" is activated. May
     * be overridden by subclasses to get informed when the 
     * browse mode is activated. The default implementation
     * is empty.
     *  
     * @param activated Whether the browse mode is activated
     */
    protected void setBrowseModeActivated(boolean activated)
    {
    }
    
    @Override
    public void attachTo(JComponent component)
    {
        component.addMouseListener(listener);
    }
    @Override
    public void detachFrom(JComponent component)
    {
        component.removeMouseListener(listener);
    }
    
    @Override
    public void setEnabled(boolean enabled)
    {
        this.enabled = enabled;
    }

    @Override
    public boolean isEnabled()
    {
        return enabled;
    }
    
}
