/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl.scene;

import java.awt.Rectangle;

/**
 * Default implementation of a {@link View}
 */
public class DefaultView implements View
{
    /**
     * The near clipping plane. 
     */
    private float nearClippingPlane;
    
    /**
     * The far clipping plane.
     */
    private float farClippingPlane;
    
    /**
     * The current aspect ratio
     */
    private float aspect;
    
    /**
     * The current viewport
     */
    private final Rectangle viewport;
    
    /**
     * Creates a new DefaultView
     */
    public DefaultView()
    {
        nearClippingPlane = 0.1f;
        farClippingPlane = 10000.0f;
        viewport = new Rectangle();
        aspect = 1.0f;
    }
    
    
    /**
     * Set the aspect ratio of this view
     * 
     * @param newAspect The aspect ratio
     */
    public void setAspect(float newAspect)
    {
        this.aspect = newAspect;
    }

    @Override
    public float getAspect()
    {
        return aspect;
    }

    /**
     * Set the near clipping plane of this view
     * 
     * @param near The near clipping plane
     */
    public void setNearClippingPlane(float near)
    {
        this.nearClippingPlane = near;
    }


    @Override
    public float getNearClippingPlane()
    {
        return nearClippingPlane;
    }


    /**
     * Set the far clipping plane of this view
     * 
     * @param far The near clipping plane
     */
    public void setFarClippingPlane(float far)
    {
        this.farClippingPlane = far;
    }


    @Override
    public float getFarClippingPlane()
    {
        return farClippingPlane;
    }
    

    @Override
    public Rectangle getViewport()
    {
        return new Rectangle(viewport);
    }

    /**
     * Set the viewport of this view
     * 
     * @param viewport The viewport
     */
    public void setViewport(Rectangle viewport)
    {
        this.viewport.x = viewport.x;
        this.viewport.y = viewport.y;
        this.viewport.width = viewport.width;
        this.viewport.height = viewport.height;
    }


}
